| Title: | Download Data From DMI via the API to the Open Data |
|---|---|
| Description: | Access the DMI API. |
| Authors: | Lars Dalby [aut, cre] (ORCID: <https://orcid.org/0000-0002-7270-6999>) |
| Maintainer: | Lars Dalby <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.5 |
| Built: | 2026-06-08 08:27:07 UTC |
| Source: | https://gitlab.au.dk/ecos/tools/r-pkgs/dmir |
Dataset downloaded via the dmi_get_climate
daneborgdaneborg
A dataframe with 12 rows and 11 variables
See the DMI documentation for further info.
The list column with paramterId has been stripped from the dataset.
Use dmi_get_climate to get the full dataset.
A simple checker function which simply determines if the download was empty or not.
dmi_check_download(data)dmi_check_download(data)
data |
json The downloaded object from |
Returns TRUE if download not empty FALSE otherwise
Get climate data from either station or a cell from the 10km or 20km grids
dmi_get_climate( parameter = NULL, station_id = NULL, cell_id = NULL, date_start = NULL, date_end = NULL, time_resolution = NULL, limit = "10", api_key = NULL )dmi_get_climate( parameter = NULL, station_id = NULL, cell_id = NULL, date_start = NULL, date_end = NULL, time_resolution = NULL, limit = "10", api_key = NULL )
parameter |
chr The parameter to be downloaded |
station_id |
chr The station ID |
cell_id |
chr The cell ID from the 10 km x 10 km grid "Det Danske Kvadratnet". See the documentation here. Use your browser to search for "cellId". |
date_start |
chr First date of observations to be downloaded. Use the format "2021-12-24". |
date_end |
chr Last date of observations to be downloaded. Use the format "2021-12-24" |
time_resolution |
chr Either day, month & year |
limit |
chr The max number of observations to download. Current max allowed by the API is 300000. To avoid possible issues with scientific notation in R this needs to be provided as character. Default is "10". |
api_key |
chr The API key to use in the call to the API.
Use |
Get gridded climate data from either 10km or the 20km grid. the 10 km x 10 km grid is also know as "Det Danske Kvadratnet".
dmi_get_grid( parameter = NULL, grid = NULL, date_start = NULL, date_end = NULL, time_resolution = NULL, limit = "10", api_key = NULL )dmi_get_grid( parameter = NULL, grid = NULL, date_start = NULL, date_end = NULL, time_resolution = NULL, limit = "10", api_key = NULL )
parameter |
chr The parameter to be downloaded |
grid |
10km or 20km |
date_start |
chr First date of observations to be downloaded. Use the format "2021-12-24". |
date_end |
chr Last date of observations to be downloaded. Use the format "2021-12-24" |
time_resolution |
chr Either day, month & year |
limit |
chr The max number of observations to download. Current max allowed by the API is 300000. To avoid possible issues with scientific notation in R this needs to be provided as character. Default is "10". |
api_key |
chr The API key to use in the call to the API.
Use |
A file (temporary) with the download.
Get meterological observations from DMI
dmi_get_met( parameter = NULL, station_id = NULL, date_start = NULL, date_end = NULL, limit = NULL, api_key = NULL )dmi_get_met( parameter = NULL, station_id = NULL, date_start = NULL, date_end = NULL, limit = NULL, api_key = NULL )
parameter |
chr The parameter to be downloaded |
station_id |
chr The station ID |
date_start |
chr First date of observations to be downloaded. Use the format "2021-12-24" |
date_end |
chr Last date of observations to be downloaded. Use the format "2021-12-24" |
limit |
chr The max number of observations to download. Current max allowed by the API is 300000. To avoid possible issues with scientific notation in R this needs to be provided as character. |
api_key |
chr The API key to use in the call to the API.
Use |
A file (temporary) with the download.
Download all DMI stations from Denmark and Greenland via the API
dmi_get_stations(api_key = NULL)dmi_get_stations(api_key = NULL)
api_key |
chr The API key to use in the call to the API.
Use |
A Simple Feature data set with the stations
The grid is available at DMI Open Data
Made available via dmir for convenience.
grid_10kmgrid_10km
A Simple feature collection with 609 features two columns:
chr, CellID from the DMI grid
int, The cellID from the DMI grid avialable via the DMI service provided to AU via the NOVANA program. See novana.dmi.dk
The grid is available at DMI Open Data
Made available via dmir for convenience.
grid_20kmgrid_20km
A Simple feature collection with 178 features two columns:
chr, CellID from the DMI grid
int, The cellID from the DMI grid avialable via the DMI service provided to AU via the NOVANA program. See novana.dmi.dk